@@ -20,7 +20,7 @@ eval {
 	require Parallel::ForkManager;
 	$parallel = 1;
 };
-my $VERSION = '1.67';
+my $VERSION = '1.68';
 
 print "\n This script will collect binned values across features\n\n";
 
@@ -56,7 +56,9 @@ my (
 	$long_data,
 	$smooth,
 	$sum,
+	$format,
 	$set_strand,
+	$groupcol,
 	$gz,
 	$cpu,
 	$help,
@@ -83,9 +85,11 @@ GetOptions(
 	'min=i'          => \$min_length, # minimum feature size
 	'long!'          => \$long_data, # collecting long data features
 	'smooth!'        => \$smooth, # do not interpolate over missing values
-	'U|sum'            => \$sum, # determine a final average for all the features
+	'U|sum!'         => \$sum, # determine a final average for all the features
+	'r|format=i'     => \$format, # decimal formatting
 	'force_strand|set_strand'  => \$set_strand, # enforce an artificial strand
 				# force_strand is preferred option, but respect the old option
+	'g|groups'       => \$groupcol, # write group column file
 	'z|gz!'          => \$gz, # compress the output file
 	'c|cpu=i'        => \$cpu, # number of execution threads
 	'h|help'         => \$help, # print the help
@@ -118,6 +122,7 @@ if ($print_version) {
 
 
 ### Check for required values
+my $formatter;
 check_defaults();
 my $start_time = time;
 my $length_i; # global value for the merged transcript length
@@ -168,6 +173,7 @@ else {
 $Data->program("$0, v $VERSION");
 
 # the number of columns already in the data array
+my $beginningcolumn = $Data->last_column; 
 my $startcolumn; # this is now calculated separately for each datasets
 
 
@@ -260,6 +266,23 @@ if ($written_file) {
 else {
 	print " unable to write data file!\n";
 }
+
+# write the column group file
+if ($groupcol) {
+	my $groupfile = $written_file;
+	$groupfile =~ s/\.txt(?:\.gz)?$/.groups.txt/;
+	my $fh = Bio::ToolBox::Data->open_to_write_fh($groupfile);
+	$fh->print("Name\tDataset\n");
+	for (my $i = $beginningcolumn + 1; $i <= $Data->last_column; $i++) {
+		my $name = $Data->name($i);
+		my $dataset = $name;
+		$dataset =~ s/:[\-\d%bp]+$//;
+		$fh->print("$name\t$dataset\n");
+	}
+	$fh->close;
+	print " wrote group column file $groupfile\n";
+}
+
 printf " Completed in %.1f minutes\n", (time - $start_time)/60;
 # done
 
@@ -351,6 +374,11 @@ sub check_defaults {
 		$smooth = 0;
 	}
 
+	# generate formatter
+	if (defined $format) {
+		$formatter = '%.' . $format . 'f';
+	}
+	
 	if ($parallel) {
 		$cpu ||= 4;
 	}
@@ -642,6 +670,7 @@ sub collect_binned_long_data {
 				'method'      => $method,
 				'stranded'    => $stranded,
 			);
+			$score = sprintf($formatter, $score) if ($formatter and $score ne '.');
 			$row->value($column, $score);
 		}
 	}	
@@ -707,6 +736,8 @@ sub record_the_bin_values {
 		
 		# calculate the value
 		my $window_score = calculate_score($method, \@scores);
+		$window_score = sprintf($formatter, $window_score) 
+			if ($formatter and $window_score ne '.');
 		
 		# record the value
 		$row->value($column, $window_score);
@@ -752,7 +783,9 @@ sub go_interpolate_values {
 				
 				# apply fractional values
 				for (my $n = $col; $n < $next_i; $n++) {
-					$row->value($n, $initial + ($fraction * ($n - $col + 1)) );
+					my $score = $initial + ($fraction * ($n - $col + 1));
+					$score = sprintf($formatter, $score) if ($formatter and $score ne '.');
+					$row->value($n, $score);
 				}
 				
 				# jump ahead
@@ -849,6 +882,7 @@ sub _set_metadata {
 	$Data->metadata($new_index, 'method' , $method);
 	$Data->metadata($new_index, 'bin_size' , $binsize . $unit);
 	$Data->metadata($new_index, 'strand' , $stranded);
+	$Data->metadata($new_index, 'decimal_format', $format) if defined $format;
 	if ($set_strand) {
 		$Data->metadata($new_index, 'strand_implied', 1);
 	}
@@ -894,6 +928,7 @@ A program to collect data in bins across a list of features.
         5p_utr|3p_utr] 
   --force_strand                      use the specified strand in input file
   --long                              collect each window independently
+  -r --format <integer>               number of decimal places for numbers
   
   Bin specification:
   -b --bins <integer>                 number of bins feature is divided (10)
@@ -906,6 +941,7 @@ A program to collect data in bins across a list of features.
   --smooth                            smoothen sparse data
   
   General options:
+  -g --groups                         write columns group index file for plotting
   -z --gz                             compress output file
   -c --cpu <integer>                  number of threads, default 4
   --noparse                           do not parse input file into SeqFeatures
@@ -1061,6 +1097,12 @@ of "long" features, for example long alignments, may be counted more
 than once in long mode when they span multiple windows. Not compatible 
 when subfeatures are enabled.
 
+=item --format E<lt>integerE<gt>
+
+Specify the number of decimal positions to format the collected scores. 
+Default is not to format, often leading to more than the intended 
+significant digits.
+
 =back
 
 =head2 Bin specification
@@ -1116,6 +1158,13 @@ from neighboring values. The default is false.
 
 =over 4
 
+=item --groups
+
+Optionally write a secondary file with the list of column group names and 
+their corresponding dataset group. This can be used to assist in designating 
+the metadata when plotting files, for example in R with pheatmap. The 
+file is named the output basename appended with F<.groups.txt>.
+
 =item --gz
 
 Specify whether (or not) the output file should be compressed with gzip.
