@@ -3,7 +3,7 @@
 # documentation at end of file
 
 use strict;
-use Getopt::Long;
+use Getopt::Long qw(:config no_ignore_case bundling);
 use Pod::Usage;
 use Net::FTP;
 use Bio::ToolBox::utility qw(
@@ -13,7 +13,7 @@ use Bio::ToolBox::utility qw(
 );
 use Bio::ToolBox::parser::ucsc;
 use Bio::ToolBox::GeneTools qw(gtf_string);
-my $VERSION = '1.54';
+my $VERSION = '1.60';
 
 print "\n A script to convert UCSC tables to GFF3 files\n\n";
 
@@ -58,28 +58,28 @@ my (
 );
 my @genetables;
 GetOptions( 
-	'ftp=s'      => \$ftp_file, # which database table to retrieve
-	'db=s'       => \$database, # which ucsc genome to use
-	'host=s'     => \$host, # the ftp server to connect to
-	'chr!'       => \$do_chromo, # include the chromosome file from ftp
-	'table=s'    => \@genetables, # the input gene table files
-	'status=s'   => \$refseqstatusf, # the refseqstatus file
-	'sum=s'      => \$refseqsumf, # the refseqsummary file
-	'kgxref=s'   => \$kgxreff, # the kgXref info file
-	'ensname=s'  => \$ensemblnamef, # the ensemblToGeneName file
-	'enssrc=s'   => \$ensemblsourcef, # the ensemblSource file
-	'chromo=s'   => \$chromof, # a chromosome file
-	'source=s'   => \$user_source, # user provided source
-	'gene!'      => \$do_gene, # include genes in output
-	'cds!'       => \$do_cds, # include CDS in output
-	'utr!'       => \$do_utr, # include UTRs in output
-	'codon!'     => \$do_codon, # include start & stop codons in output
-	'share!'     => \$share, # share common exons and UTRs
-	'name!'      => \$do_name, # assign names to CDSs, UTRs, and exons
-	'gtf!'       => \$do_gtf, # write a gtf file instead
-	'gz!'        => \$gz, # compress file
-	'help'       => \$help, # request help
-	'version'    => \$print_version, # print the version
+	'f|ftp=s'      => \$ftp_file, # which database table to retrieve
+	'd|db=s'       => \$database, # which ucsc genome to use
+	'h|host=s'     => \$host, # the ftp server to connect to
+	'chr!'         => \$do_chromo, # include the chromosome file from ftp
+	't|table=s'    => \@genetables, # the input gene table files
+	'a|status=s'   => \$refseqstatusf, # the refseqstatus file
+	's|sum=s'      => \$refseqsumf, # the refseqsummary file
+	'k|kgxref=s'   => \$kgxreff, # the kgXref info file
+	'n|ensname=s'  => \$ensemblnamef, # the ensemblToGeneName file
+	'r|enssrc=s'   => \$ensemblsourcef, # the ensemblSource file
+	'c|chromo=s'   => \$chromof, # a chromosome file
+	'source=s'     => \$user_source, # user provided source
+	'gene!'        => \$do_gene, # include genes in output
+	'cds!'         => \$do_cds, # include CDS in output
+	'utr!'         => \$do_utr, # include UTRs in output
+	'codon!'       => \$do_codon, # include start & stop codons in output
+	'share!'       => \$share, # share common exons and UTRs
+	'name!'        => \$do_name, # assign names to CDSs, UTRs, and exons
+	'g|gtf!'       => \$do_gtf, # write a gtf file instead
+	'z|gz!'        => \$gz, # compress file
+	'h|help'       => \$help, # request help
+	'v|version'    => \$print_version, # print the version
 ) or die " unrecognized option(s)!! please refer to the help documentation\n\n";
 
 # Print help
@@ -581,7 +581,7 @@ __END__
 
 ucsc_table2gff3.pl
 
-A script to convert UCSC gene tables to GFF3 annotation.
+A program to convert UCSC gene tables to GFF3 or GTF annotation.
 
 =head1 SYNOPSIS
 
@@ -589,34 +589,43 @@ A script to convert UCSC gene tables to GFF3 annotation.
    
    ucsc_table2gff3.pl [--options] --table <filename>
   
-  Options:
-  --ftp [refgene|ensgene|xenorefgene|known|all]
-  --db <text>               e.g. hg19,hg38,danRer7
-  --host <text>
-  --table <filename>
-  --status <filename>
-  --sum <filename>
-  --ensname <filename>
-  --enssrc <filename>
-  --kgxref <filename>
-  --chromo <filename>
-  --source <text>
-  --chr   | --nochr         (true)
-  --gene  | --nogene        (true)
-  --cds   | --nocds         (true)
-  --utr   | --noutr         (false)
-  --codon | --nocodon       (false)
-  --share | --noshare       (true)
-  --name  | --noname        (false)
-  --gtf
-  --gz
-  --version
-  --help
+  UCSC database options:
+  -f --ftp [refgene|ensgene|            specify what tables to retrieve from UCSC
+            xenorefgene|known|all]
+  -d --db <text>                        UCSC database name: hg19,hg38,danRer7, etc
+  -h --host <text>                      specify UCSC hostname
+  
+  Input file options:
+  -t --table <filename>                 name of table, repeat or comma list
+  -a --status <filename>                refSeqStatus file
+  -s --sum <filename>                   refSeqSummary file
+  -n --ensname <filename>               ensemblToGeneName file
+  -r --enssrc <filename>                ensemblSource file
+  -k --kgxref <filename>                kgXref file
+  -c --chromo <filename>                chromosome file
+  
+  Conversion options:
+  --source <text>                       source text, default UCSC
+  --chr   | --nochr         (true)      include chromosomes in output
+  --gene  | --nogene        (true)      assemble into genes
+  --cds   | --nocds         (true)      include CDS subfeatures
+  --utr   | --noutr         (false)     include UTR subfeatures
+  --codon | --nocodon       (false)     include start and stop codons
+  --share | --noshare       (true)      share subfeatures
+  --name  | --noname        (false)     include name
+  -g --gtf                              convert to GTF instead of GFF3
+  
+  General options:
+  -z --gz                               compress output
+  -v --version                          print version and exit
+  -h --help                             show extended documentation
 
 =head1 OPTIONS
 
 The command line flags and descriptions:
 
+=head2 UCSC database options
+
 =over 4
 
 =item --ftp [refgene|ensgene|xenorefgene|known|all]
@@ -627,19 +636,25 @@ including I<refGene>, I<ensGene>, I<xenoRefGene> mRNA gene prediction
 tables, and the UCSC I<knownGene> table (if available). Specify all to 
 download all four tables. A comma delimited list may also be provided.
 
-=item --db <text>
+=item --db E<lt>textE<gt>
 
 Specify the genome version database from which to download the requested 
 table files. See L<http://genome.ucsc.edu/FAQ/FAQreleases.html> for a 
 current list of available UCSC genomes. Examples included hg19, mm9, and 
 danRer7.
 
-=item --host <text>
+=item --host E<lt>textE<gt>
 
 Optionally provide the host FTP address for downloading the current 
 gene table files. The default is 'hgdownload.cse.ucsc.edu'.
 
-=item --table <filename>
+=back
+
+=head2 Input file options
+
+=over 4
+
+=item --table E<lt>filenameE<gt>
 
 Provide the name of a UCSC gene or gene prediction table. Tables known 
 to work include the I<refGene>, I<ensGene>, I<xenoRefGene>, and UCSC 
@@ -648,48 +663,54 @@ well as refFlat tables are supported. The file may be gzipped. When
 converting multiple tables, use this option repeatedly for each table. 
 The C<--ftp> option is recommended over using this one.
 
-=item --status <filename>
+=item --status E<lt>filenameE<gt>
 
 Optionally provide the name of the I<refSeqStatus> table file. This file 
 provides additional information for the I<refSeq>-based gene prediction 
 tables, including I<refGene>, I<xenoRefGene>, and I<knownGene> tables. 
 The file may be gzipped. The C<--ftp> option is recommended over using this.
 
-=item --sum <filename>
+=item --sum E<lt>filenameE<gt>
 
 Optionally provide the name of the I<refSeqSummary> file. This file 
 provides additional information for the I<refSeq>-based gene prediction 
 tables, including I<refGene>, I<xenoRefGene>, and I<knownGene> tables. The 
 file may be gzipped. The C<--ftp> option is recommended over using this.
 
-=item --ensname <filename>
+=item --ensname E<lt>filenameE<gt>
 
 Optionally provide the name of the I<ensemblToGeneName> file. This file 
 provides a key to translate the Ensembl unique gene identifier to the 
 common gene name. The file may be gzipped. The C<--ftp> option is 
 recommended over using this.
 
-=item --enssrc <filename>
+=item --enssrc E<lt>filenameE<gt>
 
 Optionally provide the name of the I<ensemblSource> file. This file 
 provides a key to translate the Ensembl unique gene identifier to the 
 type of transcript, provided by Ensembl as the source. The file may be 
 gzipped. The C<--ftp> option is recommended over using this.
 
-=item --kgxref <filename>
+=item --kgxref E<lt>filenameE<gt>
 
 Optionally provide the name of the I<kgXref> file. This file 
 provides additional information for the UCSC I<knownGene> gene table.
 The file may be gzipped.
 
-=item --chromo <filename>
+=item --chromo E<lt>filenameE<gt>
 
 Optionally provide the name of the chromInfo text file. Chromosome 
 and/or scaffold features will then be written at the beginning of the 
 output GFF file (when processing a single table) or written as a 
 separate file (when processing multiple tables). The file may be gzipped.
 
-=item --source <text>
+=back
+
+=head2 Conversion options
+
+=over 4
+
+=item --source E<lt>textE<gt>
 
 Optionally provide the text to be used as the GFF source. The default is 
 automatically derived from the source table file name, if recognized, or 
@@ -748,6 +769,12 @@ Specify that a GTF (version 2.5) format file should be written instead of
 GFF3. Yes, the name of the program says GFF3, but now we can output GTF 
 too, and changing the name of the program is too late now.
 
+=back
+
+=head2 General options
+
+=over 4
+
 =item --gz
 
 Specify whether the output file should be compressed with gzip.
@@ -794,10 +821,8 @@ If provided, chromosome and/or scaffold features will be written as GFF3-style
 sequence-region pragmas (even for GTF files, just in case).
 
 If you need to set up a database using UCSC annotation, you should first 
-take a look at the BioToolBox script B<db_setup.pl>, which provides a 
-convenient automated database setup based on UCSC annotation. You can also 
-find more information about loading a database in a How To document at 
-L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
+take a look at the BioToolBox script L<db_setup.pl>, which provides a 
+convenient automated database setup based on UCSC annotation.  
 
 =head1 AUTHOR
 
